from setuptools import setup, find_packages

setup(name='nagobah',
      version='0.2.2',
      description='Simple DAG-based job scheduler, expanded batch mode by xuanxuan',
      url='https://github.com/littlegump/dagobah',
      download_url="https://github.com/littlegump/dagobah/tarball/0.1.5",
      author='Travis Thieman & a little bit with xuanxuan',
      author_email='travis.thieman@gmail.com; 13060404095@163.com',
      license='WTFPL',
      packages=find_packages(),
      package_data={'dagobah': ['email/templates/basic/*',
                                'daemon/static/css/*',
                                'daemon/static/js/*',
                                'daemon/static/img/*',
                                'daemon/static/lib/*.js',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/*.js',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/*.ks',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/affix/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/alert/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/button/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/carousel/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/collapse/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/dropdown/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/modal/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/popover/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/scrollspy/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/tab/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/tooltip/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/transition/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/bootstrap/typeahead/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/extras/fontawesome/font/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/retina/*',
                                'daemon/static/lib/Kickstrap1.3.2/Kickstrap/apps/tinygrowl/*',
                                'daemon/templates/*',
                                'daemon/dagobahd.yml']},
      install_requires=['croniter==0.3.3',
                        'python-dateutil==2.1',
                        'pyyaml==3.10',
                        'flask==0.10.1',
                        'premailer==1.13',
                        'flask-login==0.2.6',
                        'semantic_version==2.3.0',
                        'paramiko==1.16.0',
                        'py-dag==1.0.0'],
      test_suite='nose.collector',
      tests_require=['nose', 'pymongo'],
      entry_points={
          'console_scripts': [
              'dagobahd = dagobah.daemon.app:daemon_entrypoint',
              'echo_dagobah_conf = dagobah:print_standard_conf',
              'nagobah = dagobah.nagobah:main',
              ],
          },
      zip_safe=False)
