// Caching: This file works by magic to turn on caching.

@importedJS: "<script class=\"extras\" type=\"text/javascript\">consoleLog('Style caching enabled.')br-consoleLog('if you expected something different, try typing \"clearCache()\"')br-</script>";
script#caching {content: @importedJS;}
